<?php

namespace Teknisa\FIN\Modules\ContaPagar\Controllers;

use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\Row;
use Teknisa\Libs\Service\CRUD as CrudService;
use Teknisa\Libs\Util\Environment;
use Teknisa\FIN\Controllers\TeknisaCrud;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\FIN\Modules\ContaPagar\Services\AjusteContaService as AjusteContaService;

/**
 * Class AjusteContaController
 * @package Teknisa\FIN\Modules\ContaPagar\Controllers
 */
class AjusteContaController extends TeknisaCrud{

    protected $dataSourceName = 'ajctpagar_tipoajpagar';

    /**
     * @param CrudService $crudService
     * @param ParameterBag $parameterBag
     * @param Environment $environment
     * @param AjusteContaService $ajusteContaService
     */
    public function __construct(CrudService $crudService, ParameterBag $parameterBag, Environment $environment, AjusteContaService $ajusteContaService)
    {
        $this->crudService  = $crudService;
        $this->parameterBag = $parameterBag;
        $this->environment  = $environment;
        $this->ajusteContaService = $ajusteContaService;
    }

    /**
     * Deleta Ajuste Conta
     * @param Row $row
     * @param Response $response
     */
    public function deletaAjusteConta(Row $row, Response $response)
    {
        try {
            // Dados do Registro
            $rows = $row->getRow();

            // Parâmetros Iniciais
            $nrorg        = $rows['NRORG'];
            $cdfilial     = $rows['CDFILIAL'];
            $cdempresa    = $rows['CDEMPRESA'];
            $valoratual   = $rows['VRATUAPAG'];
            $idajuste     = $rows['IDAJUCTPAG'];
            $cdfilirece   = $rows['CDFILIRECE'];
            $nrlanctonf   = $rows['NRLANCTONF'];
            $cdtpctpagar  = $rows['CDTPCTPAGAR'];
            $nrlanbolpag  = $rows['NRLANBOLPAG'];
            $nrseqvenpag  = $rows['NRSEQVENPAG'];
            $valorajuste  = $rows['VRAJUSTEPAG'];
            $vrajuste     = $rows['VRAJUSTEPAG'];
            $nrparcelapag = $rows['NRPARCELAPAG'];
            $dtajustepag  = $rows['DTAJUSTEPAG'];
            $cdclassfina  = $rows['CDCLASSFINA'];
            $idmovfluxo   = $rows['IDMOVFLUXO'];
            $cdajuctpag   = $rows['CDAJUCTPAG'];
            $idstatpag    = $rows['IDSTATPAG'];
            $vrsaimfluxo  = $rows['VRAJUSTEPAG'] * -1;

            // Deleta Ajuste Conta
            $this->ajusteContaService->deletaAjusteConta(
                $nrorg, $cdfilial, $cdtpctpagar, $nrlanbolpag, $cdfilirece, $nrparcelapag, $nrseqvenpag, $valorajuste,
                $nrlanctonf, $idajuste, $vrsaimfluxo, $vrajuste, $valoratual, $dtajustepag, $cdempresa,
                $cdclassfina, $idmovfluxo, $cdajuctpag, $idstatpag
            );

            // Registra Dados
            $response->addDataSet(new DataSet('deletaAjusteConta', ['success' => 'S']));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

} 