<?php

namespace Teknisa\FIN\Modules\ContaPagar\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\Model\Fiscal\Entities\Notafiscal;
use Teknisa\Model\Financeiro\Entities\Ajctpagar;
use Teknisa\Model\Financeiro\Entities\Boletpagar;
use Teknisa\Model\Financeiro\Entities\Contapagar;
use Teknisa\Model\Financeiro\Entities\Ratctpagar;
use Teknisa\Model\Contabilidade\Entities\Lanccont;

/**
 * Class AjusteTituloFactory
 * @package Teknisa\FIN\Modules\ContaPagar\Factory
 */
class AjusteContaFactory {

    protected $entityManager;

    /**
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    /**
     * Busca Ajuste Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $cdajuctpag
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @return Ajctpagar
     */
    public function buscaAjctpagar($nrorg, $cdfilial, $nrlanctonf, $cdajuctpag, $nrseqvenpag, $nrparcelapag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilial']     = $cdfilial;
        $params['nrlanctonf']   = $nrlanctonf;
        $params['cdajuctpag']   = $cdajuctpag;
        $params['nrseqvenpag']  = $nrseqvenpag;
        $params['nrparcelapag'] = $nrparcelapag;

        /** @var Ajctpagar $ajctpagar */
        $ajctpagar = $this->entityManager->getRepository(Ajctpagar::class)->findOneBy($params);

        return $ajctpagar;
    }

    /**
     * Busca Boleto Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanbolpag
     * @return Boletpagar
     */
    public function buscaBoletpagar($nrorg, $cdfilial, $nrlanbolpag){
        /** @var $params */
        $params = array();
        $params['nrorg']       = $nrorg;
        $params['cdfilial']    = $cdfilial;
        $params['nrlanbolpag'] = $nrlanbolpag;

        /** @var Boletpagar $boletpagar */
        $boletpagar = $this->entityManager->getRepository(Boletpagar::class)->findOneBy($params);

        return $boletpagar;
    }

    /**
     * Busca Conta Pagar
     * @param $nrorg
     * @param $cdfilial
     * @param $nrlanctonf
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @return Contapagar
     */
    public function buscaContapagar($nrorg, $cdfilial, $nrlanctonf, $nrseqvenpag, $nrparcelapag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilibpag']   = $cdfilial;
        $params['nrlanctonf']   = $nrlanctonf;
        $params['nrseqvenpag']  = $nrseqvenpag;
        $params['nrparcelapag'] = $nrparcelapag;

        /** @var Contapagar $contapagar */
        $contapagar = $this->entityManager->getRepository(Contapagar::class)->findOneBy($params);

        return $contapagar;
    }

    /**
     * Busca Lançamento Contábil
     * @param $nrorg
     * @param $cdempresa
     * @param $nrlanccont
     * @return Lanccont
     */
    public function buscaLanccont($nrorg, $cdempresa, $nrlanccont){
        /** @var $params */
        $params = array();
        $params['nrorg']      = $nrorg;
        $params['cdempresa']  = $cdempresa;
        $params['nrlanccont'] = $nrlanccont;

        /** @var Lanccont $lanccont */
        $lanccont = $this->entityManager->getRepository(Lanccont::class)->findBy($params);

        return $lanccont;
    }

    /**
     * @param $nrorg
     * @param $cdempresa
     * @param $nrseqvenpag
     * @param $nrparcelapag
     * @param $cdfiratctpag
     * @return Ratctpagar
     */
    public function buscaRatctpagar($nrorg, $cdempresa, $nrseqvenpag, $nrparcelapag, $cdfiratctpag){
        /** @var $params */
        $params = array();
        $params['nrorg']        = $nrorg;
        $params['cdfilial']     = $cdempresa;
        $params['nrseqvenpag']  = $nrseqvenpag;
        $params['nrparcelapag'] = $nrparcelapag;
        $params['cdfiratctpag'] = $cdfiratctpag;

        /** @var Ratctpagar $ratctpagar */
        $ratctpagar = $this->entityManager->getRepository(Ratctpagar::class)->findBy($params);

        return $ratctpagar;
    }
}